@@ -1,4 +1,4 @@
-# Copyright (C) 2012-2018 Free Software Foundation, Inc.
+# Copyright (C) 2012-2024 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,21 +15,48 @@
 
 import gdb
 
-class Recognizer(object):
+
+class StringRecognizer(object):
     def __init__(self):
         self.enabled = True
 
     def recognize(self, type_obj):
-        if type_obj.tag == 'basic_string':
-            return 'string'
+        if type_obj.tag == "basic_string":
+            return "string"
         return None
 
+
 class StringTypePrinter(object):
     def __init__(self):
-        self.name = 'string'
+        self.name = "string"
         self.enabled = True
 
     def instantiate(self):
-        return Recognizer()
+        return StringRecognizer()
+
 
 gdb.type_printers.append(StringTypePrinter())
+
+
+class OtherRecognizer(object):
+    def __init__(self):
+        self.enabled = True
+
+    def recognize(self, type_obj):
+        if type_obj.tag == "Other":
+            return "Another"
+        return None
+
+
+class OtherTypePrinter(object):
+    def __init__(self):
+        self.name = "other"
+        self.enabled = True
+
+    def instantiate(self):
+        return OtherRecognizer()
+
+
+import gdb.types
+
+gdb.types.register_type_printer(gdb.objfiles()[0], OtherTypePrinter())
